export default class Account {
    /**
     * Constructor for this SDK section.
     * @param {object} axios An axios object to make HTTP requests.
     * @param {string} baseUrl The base URL for your instance of the Web API.
     * @param {object} authHeader Holds the token and authorization method.
     */
    constructor(axios, baseUrl, authHeader) {
        this.axios = axios;
        this.baseUrl = baseUrl + "account/"
        this.authHeader = authHeader;
    }

    /**
     * Test Connection to Web API.
     */
    async testConnection() {
        let r = await this.axios.get(`${this.baseUrl}testconnection`)
        return r.data
    }

    /**
     * Athenticates a user and returns his/her credentials.
     * @param {string} username
     * @param {string} password
     */
    async getAuthenticatedUser(username, password) {
        let r = await this.axios.get(`${this.baseUrl}authenticateuser?username=${username}&password=${password}`)
        return r.data
    }

    /**
     * Returns counts of purchase orders, item receipts, and low inventory.
     * @param {Int32Array} divisionIds A user's division IDs.
     */
     async getInventorySummaries(divisionIds) {
        let r = await this.axios.post(`${this.baseUrl}getInventorySummaries`,
            { divisionIds: divisionIds },
            this.authHeader
        )
        return r.data
    }

    /**
     * Gets a user's layout for a particular grid.
     * @param {number} userId
     * @param {string} objectType 
     * @param {number} objectId
     */
    async getGridLayout(userId, objectType, objectId) {
        let url = `${this.baseUrl}getGridLayout?userId=${userId}&objectType=${objectType}`
        if (objectId != null && typeof objectId !== 'undefined')
            url += `&objectId=${objectId}`

        let r = await this.axios.get(url, this.authHeader)
        return r.data
    }

    /**
     * Adds a new grid layout.
     * @param {object} layout
     */
    async addGridLayout(layout) {
        let r = await this.axios.put(`${this.baseUrl}addGridLayout`, layout, this.authHeader)
        return r.data
    }

    /**
     * Updates the grid layout.
     * @param {object} layout
     */
    async updateGridLayout(layout) {
        let r = await this.axios.put(`${this.baseUrl}updateGridLayout`, layout, this.authHeader)
        return r.data
    }
}
