export default class Asset {
    /**
     * Constructor for this SDK section.
     * @param {object} axios An axios object to make HTTP requests.
     * @param {string} baseUrl The base URL for your instance of the Web API.
     * @param {object} authHeader Holds the token and authorization method.
     */
    constructor(axios, baseUrl, authHeader) {
        this.axios = axios;
        this.baseUrl = baseUrl + "assets/";
        this.authHeader = authHeader;
    }

    /**
     * Returns a list of assests in the specified division.
     * @param {Int32Array} divisionIds A user's division IDs.
     */
    async getAssetsInDivisions(divisionIds) {
        let r = await this.axios.post(`${this.baseUrl}getassetsindivisions`,
            { divisionIds: divisionIds },
            this.authHeader
        )
        return r.data
    }

    /**
     * Gets an asset by ID.
     * @param {number} id 
     */
    async getAsset(id) {
        let r = await this.axios.get(`${this.baseUrl}getasset?id=${id}`, this.authHeader)
        return r.data
    }
}