export default class Filter {
    /**
     * Constructor for this SDK section.
     * @param {object} axios An axios object to make HTTP requests.
     * @param {string} baseUrl The base URL for your instance of the Web API.
     * @param {object} authHeader Holds the token and authorization method.
     */
    constructor(axios, baseUrl, authHeader) {
        this.axios = axios;
        this.baseUrl = baseUrl + "sofilters/";
        this.authHeader = authHeader;
    }

    /**
     * Gets all filters for the specified user.
     * @param {number} userId
     */
    async getFiltersList(userId) {
        let r = await this.axios.get(`${this.baseUrl}getFiltersList?userId=${userId}`, this.authHeader)
        return r.data
    }

    /**
     * Gets filter groups for the specified user in a particular division.
     * @param {number} divId The division ID.
     * @param {number} userId
     */
    async getFilterGroupsByDivisionId(divId, userId) {
        let r = await this.axios.get(`${this.baseUrl}getFilterGroupsByDivisionId?divId=${divId}&userId=${userId}`, this.authHeader)
        return r.data
    }

    /**
     * Deletes a filter with the matching ID.
     * @param {number} fid The filter's ID.
     */
    async deleteFilterById(fid) {
        let r = await this.axios.get(`${this.baseUrl}deleteFilterById?fid=${fid}`, this.authHeader)
        return r.data
    }

    /**
     * Adds a new filter.
     * @param {object} filter
     */
    async addFilter(filter) {
        let r = await this.axios.post(`${this.baseUrl}addFilter`, filter, this.authHeader)
        return r.data
    }

    /**
     * Updates a filter.
     * @param {object} filter
     */
    async updateFilter(filter) {
        let r = await this.axios.post(`${this.baseUrl}updateFilter`, filter, this.authHeader)
        return r.data
    }

    /**
     * Gets a user's shared filters.
     * @param {number} userId
     * @param {Int32Array} divisionIds
     */
    async getSharedFilterItems(userId, divisionIds) {
        let r = await this.axios.post(`${this.baseUrl}getSharedFilterItems`, 
            {userId, divisionIds},
            this.authHeader 
        )
        return r.data
    }

    /**
     * Gets a user's personal filters.
     * @param {number} userId
     * @param {Int32Array} divisionIds
     */
    async getPersonalFilterItems(userId, divisionIds) {
        let r = await this.axios.post(`${this.baseUrl}getPersonalFilterItems`, 
            {userId, divisionIds},
            this.authHeader 
        )
        return r.data
    }
}