export default class Navigation {
    /**
     * Constructor for this SDK section.
     * @param {object} axios An axios object to make HTTP requests.
     * @param {string} baseUrl The base URL for your instance of the Web API.
     * @param {object} authHeader Holds the token and authorization method.
     */
    constructor(axios, baseUrl, authHeader) {
        this.axios = axios;
        this.baseUrl = baseUrl + "navigation/";
        this.authHeader = authHeader;
    }

    /**
     * Gets the top navigation items for a user.
     * @param {number} userId
     */
    async getTopMenuItems(userId) {
        let r = await this.axios.get(`${this.baseUrl}getTopMenuItems?userId=${userId}`, this.authHeader)
        return r.data
    }

    /**
     * Gets the side navigation items for a user.
     * @param {number} userId
     */
    async getLeftMenuItems(userId) {
        let r = await this.axios.get(`${this.baseUrl}getLeftMenuItems?userId=${userId}`, this.authHeader)
        return r.data
    }
}