export default class Query {
    /**
     * Constructor for this SDK section.
     * @param {object} axios An axios object to make HTTP requests.
     * @param {string} baseUrl The base URL for your instance of the Web API.
     * @param {object} authHeader Holds the token and authorization method.
     */
    constructor(axios, baseUrl, authHeader) {
        this.axios = axios;
        this.baseUrl = baseUrl + "queries/"
        this.authHeader = authHeader;
    }

    /**
     * Gets all queries in the specified division.
     * @param {number} divId The specified division ID.
     */
    async getQueriesByDivisionId(divId) {
        let r = await this.axios.get(`${this.baseUrl}getQueriesByDivisionId?divId=${divId}`, this.authHeader)
        return r.data
    }

    /**
     * Gets the results of the custom query. Supports paging
     * @param {number} queryId
     * @param {number} pageNo (Optional)
     */
    async getQueryResults(queryId, pageNo) {
        var parameters = `?queryId=${queryId}`;
        if(typeof pageNo !== 'undefined')
            parameters = `?queryId=${queryId}&pageNo=${pageNo}`;

        let r = await this.axios.get(`${this.baseUrl}queries/getQueryResults${parameters}`, this.authHeader)
        return r.data
    }
}